@@ -6,11 +6,11 @@
 # Andy Wardley's AppConfig module. It basically provides five standard
 # command-line arguments:
 #
-#	-help		display a short help statement
-#	-doc		display the full documentation (formatted pod)
-#	-version	display the version of the script
-#	-verbose	turn on verbose output
-#	-debug		turn on debugging output
+#   -help       display a short help statement
+#   -doc        display the full documentation (formatted pod)
+#   -version    display the version of the script
+#   -verbose    turn on verbose output
+#   -debug      turn on debugging output
 #
 # The -help and -doc functionality is provided by Brad Appleton's
 # Pod::Usage module. I wrote this module because I was cutting &
@@ -25,6 +25,7 @@
 #=======================================================================
 
 package AppConfig::Std;
+$AppConfig::Std::VERSION = '1.10';
 use 5.006;
 use strict;
 use warnings;
@@ -34,7 +35,6 @@ use AppConfig;
 
 use vars qw(@ISA $VERSION);
 
-$VERSION = '1.09';
 @ISA     = qw(AppConfig);
 
 #=======================================================================
@@ -42,9 +42,9 @@ $VERSION = '1.09';
 # new() - constructor
 #
 # The constructor:
-#	> invokes the AppConfig constructor with standard config
-#	> blesses the instance into this package
-#	> defines the -help, -doc, -version, and -debug options
+#   > invokes the AppConfig constructor with standard config
+#   > blesses the instance into this package
+#   > defines the -help, -doc, -version, and -debug options
 #       > configures with any additional options passed to constructor
 #
 #=======================================================================
@@ -97,9 +97,8 @@ sub args
     # If the command-line was successfully parsed (returned TRUE),
     # then check for the standard command-line switches.
     #-------------------------------------------------------------------
-    if ($result)
-    {
-	$self->_handle_std_opts();
+    if ($result) {
+        $self->_handle_std_opts();
     }
 
     return $result;
@@ -131,9 +130,8 @@ sub getopt
     # If the command-line was successfully parsed (returned TRUE),
     # then check for the standard command-line switches.
     #-------------------------------------------------------------------
-    if ($result)
-    {
-	$self->_handle_std_opts();
+    if ($result) {
+        $self->_handle_std_opts();
     }
 
     return $result;
@@ -188,15 +186,15 @@ AppConfig::Std - subclass of AppConfig that provides standard options
 =head1 SYNOPSIS
 
     use AppConfig::Std;
-    
+
     $config = AppConfig::Std->new();
-    
+
     # all AppConfig methods supported
     $config->define('foo');            # define variable foo
     $config->set('foo', 25);           # setting a variable
     $val = $config->get('foo');        # getting variable
     $val = $config->foo();             # shorthand for getting
-    
+
     $config->args(\@ARGV);             # parse command-line
     $config->file(".myconfigrc")       # read config file
 
@@ -305,21 +303,21 @@ use of the AppConfig::Std module:
     #!/usr/bin/perl -w
     use strict;
     use AppConfig::Std;
-    
+
     use vars qw( $VERSION );
     $VERSION = '1.0';
-    
+
     my $config = AppConfig::Std->new();
-    
+
     # parse command-line and handle std switches
     $config->args(\@ARGV);
-    
+
     exit 0;
-    
+
     __END__
-    
+
     =head1 NAME
-    
+
     standard pod format documentation
 
 The pod documentation is expected to have the NAME, SYNOPSIS,
@@ -328,41 +326,30 @@ for C<pod2man> for more details.
 
 =head1 SEE ALSO
 
-=over 4
-
-=item AppConfig
-
+L<AppConfig> -
 Andy Wardley's module for unifying command-line switches and
 cofiguration files into the notion of configuration variables.
 AppConfig::Std requires version 1.52+ of the module,
-which is available from CPAN:
-
-    http://www.cpan.org/modules/by-module/AppConfig/
-
-=item Pod::Usage
+which is available from CPAN.
 
+L<Pod::Usage> -
 Brad Appleton's module for extracting usage information out
 of a file's pod. This is used for the B<-doc> and B<-help> switches.
-Available from CPAN as part of the PodParser distribution:
+Available from CPAN as part of the PodParser distribution.
 
-    http://www.cpan.org/modules/by-module/Pod/
-
-=item perlpod
-
-Documentation from the perl distribution that describes
+L<perlpod|https://metacpan.org/pod/distribution/perl/pod/perlpod.pod> -
+documentation from the perl distribution that describes
 the pod format.
 
-=item pod2man
-
-Particularly the NOTES section in the documentation
+L<pod2man|https://metacpan.org/pod/distribution/podlators/scripts/pod2man> -
+particularly the NOTES section in the documentation
 which describes the sections you should include in your documentation.
 AppConfig::Std uses Pod::Usage, which assumes well-formed pod.
 
-=back
 
 =head1 REPOSITORY
 
-L<https://github.com/neilbowers/AppConfig-Std>
+L<https://github.com/neilb/AppConfig-Std>
 
 =head1 AUTHOR
 
